@@ -5,7 +5,7 @@ Arithmetic is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -91,18 +91,8 @@ pop_number_of_operands(struct arithmeticparams *p, int op,
     case GAL_ARITHMETIC_OP_SIGCLIP_MEAN:
     case GAL_ARITHMETIC_OP_MADCLIP_MEDIAN:
     case GAL_ARITHMETIC_OP_SIGCLIP_MEDIAN:
-    case GAL_ARITHMETIC_OP_MADCLIP_NUMBER:
-    case GAL_ARITHMETIC_OP_SIGCLIP_NUMBER:
-    case GAL_ARITHMETIC_OP_MADCLIP_FILL_MAD:
-    case GAL_ARITHMETIC_OP_SIGCLIP_FILL_MAD:
-    case GAL_ARITHMETIC_OP_MADCLIP_FILL_STD:
-    case GAL_ARITHMETIC_OP_SIGCLIP_FILL_STD:
-    case GAL_ARITHMETIC_OP_MADCLIP_FILL_MEAN:
-    case GAL_ARITHMETIC_OP_SIGCLIP_FILL_MEAN:
-    case GAL_ARITHMETIC_OP_MADCLIP_FILL_MEDIAN:
-    case GAL_ARITHMETIC_OP_SIGCLIP_FILL_MEDIAN:
-    case GAL_ARITHMETIC_OP_MADCLIP_FILL_NUMBER:
-    case GAL_ARITHMETIC_OP_SIGCLIP_FILL_NUMBER:
+    case GAL_ARITHMETIC_OP_MADCLIP_MASKFILLED:
+    case GAL_ARITHMETIC_OP_SIGCLIP_MASKFILLED:
       numparams=2;
       break;
     }
@@ -298,12 +288,22 @@ arithmetic_filter(void *in_prm)
 
 
         case ARITHMETIC_OP_FILTER_SIGCLIP_MEAN:
+        case ARITHMETIC_OP_FILTER_MADCLIP_MEAN:
         case ARITHMETIC_OP_FILTER_SIGCLIP_MEDIAN:
+        case ARITHMETIC_OP_FILTER_MADCLIP_MEDIAN:
           /* The median is always available with a sigma-clip, but the mean
              needs to be explicitly requested. */
           if(afp->operator == ARITHMETIC_OP_FILTER_SIGCLIP_MEAN)
             clipflags = GAL_STATISTICS_CLIP_OUTCOL_OPTIONAL_MEAN;
-          sigclip=gal_statistics_clip_sigma(tile, afp->sclip_multip,
+
+          /* Do the main operation. */
+          if(    afp->operator==ARITHMETIC_OP_FILTER_SIGCLIP_MEAN
+              || afp->operator==ARITHMETIC_OP_FILTER_SIGCLIP_MEDIAN )
+            sigclip=gal_statistics_clip_sigma(tile, afp->sclip_multip,
+                                              afp->sclip_param, clipflags,
+                                              0, 1);
+          else
+            sigclip=gal_statistics_clip_mad(tile, afp->sclip_multip,
                                             afp->sclip_param, clipflags,
                                             0, 1);
 
@@ -311,8 +311,10 @@ arithmetic_filter(void *in_prm)
           switch(afp->operator)
             {
             case ARITHMETIC_OP_FILTER_SIGCLIP_MEAN:
+            case ARITHMETIC_OP_FILTER_MADCLIP_MEAN:
               sind = GAL_STATISTICS_CLIP_OUTCOL_MEAN; break;
             case ARITHMETIC_OP_FILTER_SIGCLIP_MEDIAN:
+            case ARITHMETIC_OP_FILTER_MADCLIP_MEDIAN:
               sind = GAL_STATISTICS_CLIP_OUTCOL_MEDIAN; break;
             default:
               error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at "
@@ -378,8 +380,10 @@ wrapper_for_filter(struct arithmeticparams *p, char *token, int operator)
   size_t fsize[ARITHMETIC_FILTER_DIM];
   gal_data_t *tmp, *tmp2, *zero, *comp, *params_list=NULL;
   size_t hnfsize[ARITHMETIC_FILTER_DIM], hpfsize[ARITHMETIC_FILTER_DIM];
-  int issigclip=(operator==ARITHMETIC_OP_FILTER_SIGCLIP_MEAN
-                 || operator==ARITHMETIC_OP_FILTER_SIGCLIP_MEDIAN);
+  int isclip=(   operator==ARITHMETIC_OP_FILTER_SIGCLIP_MEAN
+              || operator==ARITHMETIC_OP_FILTER_MADCLIP_MEAN
+              || operator==ARITHMETIC_OP_FILTER_SIGCLIP_MEDIAN
+              || operator==ARITHMETIC_OP_FILTER_MADCLIP_MEDIAN );
 
 
   /* Get the input's number of dimensions. */
@@ -405,7 +409,7 @@ wrapper_for_filter(struct arithmeticparams *p, char *token, int operator)
 
   /* Based on the first popped operand's dimensions and the operator, of
      pop the necessary number of operands. */
-  nparams = ndim + (issigclip ? 2 : 0 );
+  nparams = ndim + (isclip ? 2 : 0 );
   for(i=0;i<nparams;++i)
     {
       /* Add this to the list of parameters. */
@@ -422,7 +426,7 @@ wrapper_for_filter(struct arithmeticparams *p, char *token, int operator)
 
   /* If this is a sigma-clipping filter, the top two operands are the
      sigma-clipping parameters. */
-  if(issigclip)
+  if(isclip)
     {
       /* Read the sigma-clipping multiple (first element in the list). */
       tmp=gal_list_data_pop(&params_list);
@@ -507,6 +511,7 @@ wrapper_for_filter(struct arithmeticparams *p, char *token, int operator)
             { hnfsize[i]=fsize[i]/2; hpfsize[i]=fsize[i]/2-1; }
         }
 
+
       /* For a test.
       printf("fsize: %zu, %zu\n", fsize[0], fsize[1]);
       printf("hnfsize: %zu, %zu\n", hnfsize[0], hnfsize[1]);
@@ -519,11 +524,13 @@ wrapper_for_filter(struct arithmeticparams *p, char *token, int operator)
         {
         case ARITHMETIC_OP_FILTER_MEDIAN:
         case ARITHMETIC_OP_FILTER_SIGCLIP_MEDIAN:
+        case ARITHMETIC_OP_FILTER_MADCLIP_MEDIAN:
           type=afp.input->type;
           break;
 
         case ARITHMETIC_OP_FILTER_MEAN:
         case ARITHMETIC_OP_FILTER_SIGCLIP_MEAN:
+        case ARITHMETIC_OP_FILTER_MADCLIP_MEAN:
           type=GAL_TYPE_FLOAT64;
           break;
 
@@ -1257,9 +1264,8 @@ arithmetic_tofile(struct arithmeticparams *p, char *token, int freeflag)
   popped->wcs=p->refdata.wcs;
   if(popped->ndim==1 && p->onedasimage==0)
     gal_table_write(popped, NULL, NULL, p->cp.tableformat, filename,
-                    "ARITHMETIC", 0);
-  else
-    gal_fits_img_write(popped, filename, NULL, PROGRAM_NAME);
+                    "ARITHMETIC", 0, 0);
+  else gal_fits_img_write(popped, filename, NULL, 0);
   if(!p->cp.quiet)
     printf(" - Write: %s\n", filename);
 
@@ -1468,8 +1474,12 @@ arithmetic_set_operator(char *string, size_t *num_operands, int *inlib)
         { op=ARITHMETIC_OP_FILTER_MEDIAN;         *num_operands=0; }
       else if (!strcmp(string, "filter-sigclip-mean"))
         { op=ARITHMETIC_OP_FILTER_SIGCLIP_MEAN;   *num_operands=0; }
+      else if (!strcmp(string, "filter-madclip-mean"))
+        { op=ARITHMETIC_OP_FILTER_MADCLIP_MEAN;   *num_operands=0; }
       else if (!strcmp(string, "filter-sigclip-median"))
         { op=ARITHMETIC_OP_FILTER_SIGCLIP_MEDIAN; *num_operands=0; }
+      else if (!strcmp(string, "filter-madclip-median"))
+        { op=ARITHMETIC_OP_FILTER_MADCLIP_MEDIAN; *num_operands=0; }
       else if (!strcmp(string, "erode"))
         { op=ARITHMETIC_OP_ERODE;                 *num_operands=0; }
       else if (!strcmp(string, "dilate"))
@@ -1503,7 +1513,7 @@ arithmetic_set_operator(char *string, size_t *num_operands, int *inlib)
       else if (!strcmp(string, "collapse-mean"))
         { op=ARITHMETIC_OP_COLLAPSE_MEAN;         *num_operands=0; }
       else if (!strcmp(string, "collapse-number"))
-        { op=ARITHMETIC_OP_COLLAPSE_MEDIAN;       *num_operands=0; }
+        { op=ARITHMETIC_OP_COLLAPSE_NUMBER;       *num_operands=0; }
       else if (!strcmp(string, "collapse-median"))
         { op=ARITHMETIC_OP_COLLAPSE_MEDIAN;       *num_operands=0; }
       else if (!strcmp(string, "collapse-madclip-mad"))
@@ -1744,7 +1754,9 @@ arithmetic_operator_run(struct arithmeticparams *p, int operator,
         case ARITHMETIC_OP_FILTER_MEAN:
         case ARITHMETIC_OP_FILTER_MEDIAN:
         case ARITHMETIC_OP_FILTER_SIGCLIP_MEAN:
+        case ARITHMETIC_OP_FILTER_MADCLIP_MEAN:
         case ARITHMETIC_OP_FILTER_SIGCLIP_MEDIAN:
+        case ARITHMETIC_OP_FILTER_MADCLIP_MEDIAN:
           wrapper_for_filter(p, operator_string, operator);
           break;
 
@@ -1922,7 +1934,7 @@ arithmetic_final_data(struct arithmeticparams *p)
 void
 reversepolish(struct arithmeticparams *p)
 {
-  char *printnum;
+  char *printnum=NULL;
   struct operand *otmp;
   size_t num_operands=0;
   gal_list_str_t *token;
@@ -1979,8 +1991,10 @@ reversepolish(struct arithmeticparams *p)
          isn't an operator. */
       else
         {
-          operator=arithmetic_set_operator(token->v, &num_operands, &inlib);
-          arithmetic_operator_run(p, operator, token->v, num_operands, inlib);
+          operator=arithmetic_set_operator(token->v, &num_operands,
+                                           &inlib);
+          arithmetic_operator_run(p, operator, token->v, num_operands,
+                                  inlib);
         }
 
       /* Increment the token counter. */
@@ -2022,7 +2036,8 @@ reversepolish(struct arithmeticparams *p)
       printnum=gal_type_to_string(data->array, data->type, 0);
       printf("%s\n", printnum);
 
-      /* Clean up. */
+      /* Clean up (don't set it to 'NULL', this is used to specify if a
+         file was created in the end or not). */
       free(printnum);
     }
   else
@@ -2039,15 +2054,29 @@ reversepolish(struct arithmeticparams *p)
         { if(data->comment) free(data->comment);
           gal_checkset_allocate_copy(p->metacomment, &data->comment); }
 
-      /* Put a copy of the WCS structure from the reference image, it
-         will be freed while freeing 'data'. */
+      /* Put a copy of the WCS structure from the reference image, it will
+         be freed while freeing 'data'. But start the file with the 0-th
+         HDU keywords.*/
+
       if(data->ndim==1 && p->onedasimage==0)
-        gal_table_write(data, NULL, NULL, p->cp.tableformat,
-                        p->onedonstdout ? NULL : p->cp.output,
-                        "ARITHMETIC", 0);
+        {
+          /* The keywords HDU should only be created when a FITS file is to
+             be made; not when the output should go to a text file or the
+             standard output. */
+          if( p->onedonstdout==0
+              && gal_fits_name_is_fits(p->cp.output)==0 )
+            gal_fits_key_write(p->cp.ckeys, p->cp.output, "0", "NONE",
+                               1, 1);
+          gal_table_write(data, NULL, NULL, p->cp.tableformat,
+                          p->onedonstdout ? NULL : p->cp.output,
+                          "ARITHMETIC", 0, 0);
+        }
       else
-        for(tmp=data; tmp!=NULL; tmp=tmp->next)
-          gal_fits_img_write(tmp, p->cp.output, NULL, PROGRAM_NAME);
+        {
+          gal_fits_key_write(p->cp.ckeys, p->cp.output, "0", "NONE", 1, 1);
+          for(tmp=data; tmp!=NULL; tmp=tmp->next)
+            gal_fits_img_write(tmp, p->cp.output, NULL, 0);
+        }
 
       /* Let the user know that the job is done. */
       if(!p->cp.quiet)
@@ -2088,7 +2117,7 @@ reversepolish(struct arithmeticparams *p)
 
 
 /***************************************************************/
-/*************             Top function            *************/
+/*************         Top-level function          *************/
 /***************************************************************/
 void
 arithmetic(struct arithmeticparams *p)
