@@ -5,7 +5,7 @@ CosmicCalculator is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -28,8 +28,6 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <stdio.h>
 #include <string.h>
 
-#include <gsl/gsl_const_mksa.h>
-
 #include <gnuastro/fits.h>
 #include <gnuastro/table.h>
 #include <gnuastro/pointer.h>
@@ -407,12 +405,13 @@ ui_check_only_options(struct cosmiccalparams *p)
 
   /* Check if the density fractions add up to 1 (within floating point
      error). */
-  if( sum > (1+1e-8) || sum < (1-1e-8) )
-    error(EXIT_FAILURE, 0, "sum of fractional densities is not 1, but "
-          "%.8f. The cosmological constant ('olambda'), matter "
-          "('omatter') and radiation ('oradiation') densities are given "
-          "as %.8f, %.8f, %.8f", sum, p->olambda, p->omatter,
-          p->oradiation);
+  if( (sum > (1+1e-8) || sum < (1-1e-8)) && p->cp.quiet==0)
+    error(EXIT_SUCCESS, 0, "WARNING: non-flat FLRW model: the curvature "
+          "density parameter is %.8f; therefore angular diameter based "
+          "distances like '--angulardiamdist' or '--arcsectandist' will "
+          "be wrong in Gnuastro's current implementation; see "
+          "https://savannah.gnu.org/bugs/?65195. This warning message "
+          "can be disabled with '--quiet'", 1.0-sum);
 
   /* Make sure that '--listlines' and '--listlinesatz' aren't called
      together. */
@@ -493,7 +492,7 @@ ui_list_lines(struct cosmiccalparams *p)
     {
       /* Get the wavelength (in angstroms) for this line and print it. */
       ang=gal_speclines_line_angstrom(i);
-      printf("%-20g%s\n",
+      printf("%-15.3f %s\n",
              ( p->listlinesatz
                ? ( ang * (1+p->redshift) ) : ang ) * p->lineunitmultip,
              gal_speclines_line_name(i));
@@ -506,7 +505,7 @@ ui_list_lines(struct cosmiccalparams *p)
       /* Get the wavelength (in angstroms) for this line and print it. */
       j=i+GAL_SPECLINES_LIMIT_LYMAN;
       ang=gal_speclines_line_angstrom(j);
-      printf("%-20g%s\n",
+      printf("%-15.3f %s\n",
              ( p->listlinesatz
                ? ( ang * (1+p->redshift) ) : ang ) * p->lineunitmultip,
              gal_speclines_line_name(j));
