@@ -728,8 +728,10 @@ onecrop(struct onecropparams *crp)
       /* Make the output FITS image and initialize it with an array of NaN
          or BLANK values. But only when '--oneelemstdout' isn't called and
          the output is single-element. */
+      crp->outinstdout=0;
       if(crp->outfits==NULL && !( p->oneelemstdout && hasoneelem) )
         onecrop_make_array(crp, fpixel_i, lpixel_i, fpixel_o, lpixel_o);
+      else crp->outinstdout=1;
       ofp=crp->outfits;
 
 
