@@ -16,7 +16,7 @@
 #   Mohammad Akhlaghi <mohammad@akhlaghi.org>
 #   Carlos Morales-Socorro <cmorsoc@gmail.com>
 #   Sepideh Eskandarlou <sepideh.eskandarlou@gmail.com>
-# Copyright (C) 2021-2023 Free Software Foundation, Inc.
+# Copyright (C) 2021-2024 Free Software Foundation, Inc.
 #
 # Gnuastro is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free
@@ -37,7 +37,10 @@ set -e
 
 # 'LC_NUMERIC' is responsible for formatting numbers printed by the OS.  It
 # prevents floating points like '23,45' instead of '23.45'.
-export LC_NUMERIC=C
+sys_lang=$LANG
+export LANG=C
+sys_lcnumeric=$LC_NUMERIC
+export LC_NUMERIC="en_US.UTF-8"
 
 
 
@@ -45,6 +48,7 @@ export LC_NUMERIC=C
 
 # Default option values (can be changed with options on the command-line).
 hdu=1
+mode=""
 quiet=""
 center=""
 keeptmp=0
@@ -141,7 +145,7 @@ EOF
 print_version() {
     cat <<EOF
 $scriptname (GNU Astronomy Utilities) $version
-Copyright (C) 2020-2023 Free Software Foundation, Inc.
+Copyright (C) 2020-2024 Free Software Foundation, Inc.
 License GPLv3+: GNU General public license version 3 or later.
 This is free software: you are free to change and redistribute it.
 There is NO WARRANTY, to the extent permitted by law.
@@ -317,8 +321,6 @@ do
         -p=*|--position-angle=*)   positionangle="${1#*=}";                             check_v "$1" "$positionangle";  shift;;
         -p*)                       positionangle=$(echo "$1"  | sed -e's/-p//');        check_v "$1" "$positionangle";  shift;;
 
-
-
         # Output parameters
         -k|--keeptmp)     keeptmp=1; shift;;
         -k*|--keeptmp=*)  on_off_option_error --keeptmp -k;;
@@ -483,7 +485,13 @@ fi
 # Make sure the value to '--mode' is either 'wcs' or 'img'. Note: '-o'
 # means "or" and is preferred to '[ ] || [ ]' because only a single
 # invocation of 'test' is done. Run 'man test' for more.
-if [ "$mode" = wcs     -o      $mode = "img" ]; then
+if [ x"$mode"  = x ]; then
+    cat <<EOF
+$scriptname: '--mode' (or '-O') is mandatory. It takes one of the following two values: 'img' (for pixel coordinates) or 'wcs' (for celestial coordinates)
+EOF
+    exit 1
+fi
+if [ "$mode" = wcs -o "$mode" = img ]; then
     junk=1
 else
     cat <<EOF
@@ -510,19 +518,17 @@ fi
 # output, it will be used for saving the output file. If the user does not
 # specify a output name, then a default value containing the center will be
 # generated.
-objectid="$xcoord"_"$ycoord"
+objectid="$xcoord"-"$ycoord"
 bname_prefix=$(basename "$inputs" | sed 's/\.fits/ /' | awk '{print $1}')
 if [ x"$tmpdir" = x ]; then \
-  tmpdir=$(pwd)/"$bname_prefix"_stamp
+  tmpdir=$(pwd)/"$bname_prefix"-stamp-$objectid
 fi
 
-if [ -d "$tmpdir" ]; then
-  junk=1
-else
-  mkdir -p "$tmpdir"
-fi
+# Existance of the temporary directory (delete it if already exists).
+if [ -d "$tmpdir" ]; then  rm -r "$tmpdir"; fi
+mkdir "$tmpdir"
 
-# Output
+# Output.
 if [ x"$output" = x ]; then
   output="$bname_prefix"_stamp_$objectid.fits
 fi
@@ -565,7 +571,7 @@ fi
 # We are setting '--checkcenter=0' in Crop so it doesn't check if the
 # central pixel is covered or not (we may be interested in the outer parts
 # of the PSF of a star that is centered outside of the image).
-cropped=$tmpdir/cropped-$objectid.fits
+cropped=$tmpdir/cropped.fits
 astcrop $inputs --hdu=$hdu --mode=img --checkcenter=0 \
         --width=$xwidthinpix,$ywidthinpix \
         --center=$xcenter,$ycenter \
@@ -632,13 +638,13 @@ EOF
 
     else
         # To help in debugging (when '--quiet' is not called)
-        if [ x"$quiet" = x ]; then
+        if [ x"$quiet" = x ] && [ x"$center" != x ]; then
             echo "$scriptname: $segment: at $center, found clump $clab in object $olab"
         fi
 
         # Crop the object and clump image to same size as desired stamp.
-        cropclp=$tmpdir/cropped-clumps-$objectid.fits
-        cropobj=$tmpdir/cropped-objects-$objectid.fits
+        cropclp=$tmpdir/cropped-clumps.fits
+        cropobj=$tmpdir/cropped-objects.fits
         astcrop $segment --hdu=OBJECTS --mode=img \
                 --center=$xcenter,$ycenter \
                 --width=$xwidthinpix,$ywidthinpix --output=$cropobj $quiet
@@ -647,7 +653,7 @@ EOF
                 --width=$xwidthinpix,$ywidthinpix --output=$cropclp $quiet
 
         # Mask all the undesired regions.
-        cropped_masked=$tmpdir/cropped-masked-$objectid.fits
+        cropped_masked=$tmpdir/cropped-masked.fits
         astarithmetic $cropped --hdu=1 set-i --output=$cropped_masked $quiet \
                       $cropobj --hdu=1 set-o \
                       $cropclp --hdu=1 set-c \
@@ -656,7 +662,6 @@ EOF
                       1 dilate set-cmask \
                       o o $olab eq 0 where set-omask \
                       i omask cmask or nan where
-
     fi
 
     # Apply the signal-to-noise threshold if the user provided one, and
@@ -666,49 +671,47 @@ EOF
         # Mask all the pixels that are below the threshold based on the
         # signal to noise value which is obtained form the SKY_STD. Finally
         # label the separate regions.
-	cropsnt=$tmpdir/cropped-snt-$objectid.fits
-	cropstd=$tmpdir/cropped-std-$objectid.fits
-        croplab=$tmpdir/cropped-lab-$objectid.fits
-	astcrop $segment --hdu=SKY_STD --mode=img \
+        cropsnt=$tmpdir/cropped-snt.fits
+        cropstd=$tmpdir/cropped-std.fits
+        croplab=$tmpdir/cropped-lab.fits
+        astcrop $segment --hdu=SKY_STD --mode=img \
                 --center=$xcenter,$ycenter \
                 --width=$xwidthinpix,$ywidthinpix \
-		--output=$cropstd $quiet
+                --output=$cropstd $quiet
 
         # Fill the NAN pixels with maximum value of the image plus one (so
         # the fill value is not present in the image).
         fillval=$(astarithmetic $cropped_masked maxvalue 1 + -q)
-        fill=$tmpdir/cropped-masked-fill-nan-pix-$objectid.fits
+        fill=$tmpdir/cropped-masked-fill-nan-pix.fits
         astarithmetic $cropped_masked set-i i i isblank $fillval \
                       where --output=$fill
 
         # Apply the threshold and label the regions above the threshold.
         astarithmetic $fill -h1 set-v \
-		      $cropstd -h1        set-s \
-		      v s /               set-sn \
-		      v sn $snthresh lt \
-		      2 dilate nan where set-all \
+                      $cropstd -h1        set-s \
+                      v s /               set-sn \
+                      v sn $snthresh lt \
+                      2 dilate nan where set-all \
                       all tofilefree-$cropsnt \
                       all isnotblank 2 connected-components \
                       --output=$croplab
 
         # Extract the label of the central coordinate.
-        id=$(astcrop $croplab -h1 --mode=wcs \
+        id=$(astcrop $croplab -h1 --mode=$mode \
                      --center=$xcoord,$ycoord \
                      --widthinpix --width=1 --oneelemstdout -q)
 
-        # Mask all the pixels that do not belong to the main object.
-        msk=$tmpdir/mask-$objectid.fits
-        astarithmetic $cropsnt $croplab $id ne nan where -g1 \
-                      --output=$msk.fits
+        # Mask all the pixels that do not belong to the main object and set
+        # all the originally NaN-valued pixels to NaN again.
+        msk=$tmpdir/mask.fits
+        astarithmetic $cropsnt $croplab $id ne nan where set-i \
+                      i i $fillval eq nan where -g1 --output=$msk
 
-        # Set all the originally NaN-valued pixels to NaN again.
-        astarithmetic $msk.fits set-i i i $fillval eq nan where \
-                      --output=$msk
-
-        # Clean up.
-	mv $msk $cropped_masked
+        # Set the masked image to the desired output of this step.
+        mv $msk $cropped_masked
     fi
 
+# No '--segment' provided.
 else
     cropped_masked=$cropped
 fi
@@ -778,7 +781,7 @@ if [ $nocentering = 0 ]; then
 
     # Read the overlap range from the 'ICF1PIX' keyword (which is printed
     # in all outputs of Crop).
-    overlaprange=$(astfits $cropped -h1 --keyvalue=ICF1PIX -q \
+    overlaprange=$(astfits $cropped -h0 --keyvalue=ICF1PIX -q \
                        | sed -e's|:| |g' -e's|,| |')
 
     # Calculate the position of the bottom-left pixel of the cropped image
@@ -810,13 +813,13 @@ if [ $nocentering = 0 ]; then
 
     # Warp image based on the measured displacement (first component of the
     # output above).
-    warpped=$tmpdir/cropped-masked-warpforcenter-$objectid.fits
+    warpped=$tmpdir/cropped-masked-warpforcenter.fits
     DXY=$(echo "$warpcoord" | awk '{print $1}')
     astwarp $cropped_masked --translate=$DXY --output=$warpped
 
     # Crop image based on the calculated shift (second component of the
     # output above).
-    centermsk=$tmpdir/cropped-masked-centered-$objectid.fits
+    centermsk=$tmpdir/cropped-masked-centered.fits
     CXY=$(echo "$warpcoord" | awk '{print $2}')
     astcrop $warpped -h1 \
             --mode=img --output=$centermsk \
@@ -844,7 +847,7 @@ if [ x"$normradiusmin" != x   -a   x"$normradiusmax" != x ]; then
     # Otherwise, compute the radial profile up to the outer part of the
     # ring for the normalization (to not wast CPU time). If the user
     # specifies sigma clip parameters, use them.
-    radialprofile=$tmpdir/rprofile-$objectid.fits
+    radialprofile=$tmpdir/rprofile.fits
     maxr=$(echo "$normradiusmax" | awk '{print $1+1}')
     if [ x"$sigmaclip" = x ]; then finalsigmaclip=""
     else                           finalsigmaclip="--sigmaclip=$sigmaclip";
@@ -867,9 +870,9 @@ if [ x"$normradiusmin" != x   -a   x"$normradiusmax" != x ]; then
     values=$(asttable $radialprofile $quiet \
                       --range=1,$normradiusmin,$normradiusmax)
     if ! normvalue=$(echo "$values" \
-                          | aststatistics --column=2 --$normop \
-                                          $finalsigmaclip -q \
-                          2> /dev/null); then
+                         | aststatistics --column=2 --$normop \
+                                         $finalsigmaclip -q \
+                                         2> /dev/null); then
         normvalue=nan
     fi
 else
@@ -924,6 +927,7 @@ if [ x"$quiet" = x ] && [ $normvalue = nan ]; then all_nan_warning; fi
 
 
 
+
 # Remove temporary files
 # ----------------------
 #
@@ -932,3 +936,12 @@ if [ x"$quiet" = x ] && [ $normvalue = nan ]; then all_nan_warning; fi
 if [ $keeptmp = 0 ]; then
     rm -r $tmpdir
 fi
+
+
+
+
+
+# The script has finished, reset the original language to the system's
+# default language.
+export LANG=$sys_lang
+export LC_NUMERIC=$sys_lcnumeric
