@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -81,8 +81,8 @@ gal_data_alloc(void *array, uint8_t type, size_t ndim, size_t *dsize,
           __func__, sizeof *out);
 
   /* Initialize the allocated array. */
-  gal_data_initialize(out, array, type, ndim, dsize, wcs, clear, minmapsize,
-                      quietmmap, name, unit, comment);
+  gal_data_initialize(out, array, type, ndim, dsize, wcs, clear,
+                      minmapsize, quietmmap, name, unit, comment);
 
   /* Return the final structure. */
   return out;
@@ -120,7 +120,7 @@ gal_data_initialize(gal_data_t *data, void *array, uint8_t type,
 
   /* Do the simple copying cases. For the display elements, set them all to
      impossible (negative) values so if not explicitly set by later steps,
-     the default values are used if/when printing.*/
+     the default values are used if/when printing. */
   data->flag       = 0;
   data->status     = 0;
   data->disp_width = -1;
@@ -175,7 +175,7 @@ gal_data_initialize(gal_data_t *data, void *array, uint8_t type,
 
           /* Print a warning if the size in this dimension is too
              large. May happen when the user (mistakenly) writes a negative
-             value in this dimension.. */
+             value in this dimension. */
           if (dsize[i] >= data_size_limit / 2)
             fprintf(stderr, "%s: WARNING: dsize[%zu] value %zu is probably "
                     "a mistake: it exceeds the limit %zu", __func__, i,
@@ -245,17 +245,17 @@ gal_data_alloc_empty(size_t ndim, size_t minmapsize, int quietmmap)
 
 
 /* Free the allocated contents of a data structure, not the structure
-   itsself. The reason that this function is separate from 'gal_data_free'
+   itself. The reason that this function is separate from 'gal_data_free'
    is that the data structure might be allocated as an array (statically
    like 'gal_data_t da[20]', or dynamically like 'gal_data_t *da;
    da=malloc(20*sizeof *da);'). In both cases, a loop will be necessary to
    delete the allocated contents of each element of the data structure
-   array, but not the structure its self. After that loop, if the array of
+   array, but not the structure itself. After that loop, if the array of
    data structures was statically allocated, you don't have to do
    anything. If it was dynamically allocated, we just have to run
    'free(da)'.
 
-   Since we aren't freeing the 'gal_data_t' its-self, after the allocated
+   Since we aren't freeing the 'gal_data_t' itself, after the allocated
    space for each pointer is freed, the pointer is set to NULL for safety
    (to avoid possible re-calls).
 */
@@ -302,7 +302,7 @@ gal_data_free_contents(gal_data_t *data)
 
 
 /* Free the contents of the data structure and the data structure
-   itsself. */
+   itself. */
 void
 gal_data_free(gal_data_t *data)
 {
@@ -388,7 +388,7 @@ gal_data_array_free(gal_data_t *dataarr, size_t size, int free_array)
 {
   size_t i;
 
-  /* If its NULL, don't do anything. */
+  /* If it is NULL, don't do anything. */
   if(dataarr==NULL) return;
 
   /* First free all the contents. */
