@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2017-2023 Free Software Foundation, Inc.
+Copyright (C) 2017-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -918,7 +918,7 @@ dimension_csb_copy(gal_data_t *in, size_t from, gal_data_t *work,
 static gal_data_t *
 dimension_collapse_sortbased_operation(struct dimension_sortbased_p *p,
                                        gal_data_t *work, uint8_t clipflags,
-                                       uint8_t isfill)
+                                       uint8_t isfill, size_t wdsize)
 {
   gal_data_t *out=NULL;
 
@@ -928,6 +928,7 @@ dimension_collapse_sortbased_operation(struct dimension_sortbased_p *p,
     case DIMENSION_COLLAPSE_MEDIAN:
       out=gal_statistics_median(work, 1);
       break;
+
     case DIMENSION_COLLAPSE_MADCLIP_MAD:
     case DIMENSION_COLLAPSE_MADCLIP_STD:
     case DIMENSION_COLLAPSE_MADCLIP_MEAN:
@@ -941,8 +942,8 @@ dimension_collapse_sortbased_operation(struct dimension_sortbased_p *p,
       /* When we are dealing with a clip-fill operator, the order of
          the elements matter, so we don't want it to be done inplace.*/
       out=gal_statistics_clip_mad(work, p->sclipmultip,
-                                   p->sclipparam, clipflags,
-                                   isfill?0:1, 1);
+                                  p->sclipparam, clipflags,
+                                  isfill?0:1, 1);
       break;
 
     case DIMENSION_COLLAPSE_SIGCLIP_MAD:
@@ -967,6 +968,13 @@ dimension_collapse_sortbased_operation(struct dimension_sortbased_p *p,
             "recognized", __func__, PACKAGE_BUGREPORT, p->operator);
     }
 
+  /* All the statistical operators that are based on sorting will free the
+     input array if it doesn't have any elements! But we are re-using the
+     'work' array many times. So we need to re-allocate the array here. */
+  if(work->array==NULL)
+    work->array=gal_pointer_allocate(work->type, wdsize, 0, __func__,
+                                     "work->array");
+
   /* Return the output. */
   return out;
 }
@@ -979,10 +987,11 @@ static gal_data_t *
 dimension_collapse_sortbased_fill(struct dimension_sortbased_p *p,
                                   gal_data_t *fstat, gal_data_t *work,
                                   gal_data_t *conv, uint8_t clipflags,
-                                  int check)
+                                  size_t wdsize, int check)
 {
-  size_t one=1;
   int std1_mad0=0;
+  uint8_t *u, *uf;
+  size_t one=1, sumflag;
   float *farr=fstat->array;
   gal_data_t *formask=conv?conv:work, *out=NULL;
   gal_data_t *tmp, *multip, *upper, *lower, *center, *spread;
@@ -1068,6 +1077,13 @@ dimension_collapse_sortbased_fill(struct dimension_sortbased_p *p,
   tmp=gal_binary_erode(tmp, 2, formask->ndim, 1);
   tmp=gal_binary_dilate(tmp, formask->ndim==1?4:2, formask->ndim, 1);
 
+  /* If the covered area is larger than a certain fraction of the
+     area, flag the whole dataset. */
+  sumflag=0;
+  uf=(u=tmp->array)+tmp->size; do sumflag+=*u; while(++u<uf);
+  if(sumflag>0.95*tmp->size)
+    {uf=(u=tmp->array)+tmp->size; do *u=1; while(++u<uf);}
+
   /* Apply the flag onto the input (to set the pixels to NaN). */
   gal_blank_flag_apply(work, tmp);
 
@@ -1087,7 +1103,8 @@ dimension_collapse_sortbased_fill(struct dimension_sortbased_p *p,
   /* Apply the operation: note that 'isfill' is zero here because we don't
      care about the order of elements any more ('isfill' is only used to do
      the operation inplace or not). */
-  out=dimension_collapse_sortbased_operation(p, work, clipflags, 0);
+  out=dimension_collapse_sortbased_operation(p, work, clipflags, 0,
+                                             wdsize);
 
   /* Clean up and return. */
   gal_data_free(tmp);
@@ -1289,13 +1306,15 @@ dimension_collapse_sortbased_worker(void *in_prm)
 
       /* Do the necessary statistical operation. */
       stat=dimension_collapse_sortbased_operation(p, conv?conv:work,
-                                                  clipflags, isfill);
+                                                  clipflags, isfill,
+                                                  wdsize);
 
       /* If this is a "filling" operation, then repeat the operation with
          the fill. */
       if(isfill)
         stat=dimension_collapse_sortbased_fill(p, stat, work, conv,
-                                               clipflags, index==-1);
+                                               clipflags, wdsize,
+                                               index==-1);
 
       /* Set the index in the output 'stat' array. These can't be set in
          the main operation 'switch' because the functions are different,
@@ -1783,21 +1802,32 @@ gal_dimension_collapse_sclip_fill_number(gal_data_t *in, size_t c_dim,
 size_t
 gal_dimension_remove_extra(size_t ndim, size_t *dsize, struct wcsprm *wcs)
 {
-  size_t i, j;
+  size_t i, j, size=1;
 
-  for(i=0;i<ndim;++i)
-    if(dsize[i]==1)
-      {
-        /* Correct the WCS. */
-        if(wcs) gal_wcs_remove_dimension(wcs, ndim-i);
+  /* When there is only one element in the dataset, "extra" dimensions are
+     not defined. This is because we define "extra" by dimensions of length
+     1, so when there is only a single element everything will be "extra"
+     and the function will return 0 dimensions!  See
+     https://savannah.gnu.org/bugs/index.php?65833 for example.  Therefore,
+     the dimensions should be preserved and this function should not do
+     anything. */
+  for(i=0;i<ndim;++i) size*=dsize[i];
+  if(size>1)
+    {
+      for(i=0;i<ndim;++i)
+        if(dsize[i]==1)
+          {
+            /* Correct the WCS. */
+            if(wcs) gal_wcs_remove_dimension(wcs, ndim-i);
 
-        /* Shift all subsequent dimensions to replace this one. */
-        for(j=i;j<ndim-1;++j) dsize[j]=dsize[j+1];
+            /* Shift all subsequent dimensions to replace this one. */
+            for(j=i;j<ndim-1;++j) dsize[j]=dsize[j+1];
 
-        /* Decrement the 'i' and the total number of dimension. */
-        --i;
-        --ndim;
-      }
+            /* Decrement the 'i' and the total number of dimension. */
+            --i;
+            --ndim;
+          }
+    }
 
   /* Return the number of dimensions. */
   return ndim;
